==> v1.7.0.4.zip: bypass-paywalls-firefox-clean/README.md <==
# Bypass Paywalls Clean for Firefox

* [Installation](#installation)
* [List of supported websites](#list-of-supported-websites)
* [Sites with limited number of free articles](#sites-with-limited-number-of-free-articles)
* [New site requests](#new-site-requests)
* [Add custom site](#add-custom-site)
* [Troubleshooting](#troubleshooting)
* [Changelog-releases](#changelog-releases)
* [Pull Requests](#pull-requests)
* [Show your support](#show-your-support)
* [License](#license)

### Installation
 [Download and install the latest version](https://github.com/magnolia1234-new/bypass-paywalls-firefox-clean/releases/download/v1.7.0.4/bypass_paywalls_clean-1.7.0.4-an+fx.xpi)
 Or first visit the [releases page](https://github.com/magnolia1234-new/bypass-paywalls-firefox-clean/releases).
 Here you can also find a limited permissions version (custom sites not working though).
 Install add-on by downloading xpi-file (assets).

### List of supported websites
#### United States of America
##### World news
[First Things](https://www.firstthings.com) -
[Foreign Policy](https://www.foreignpolicy.com) -
[Harper's Magazine](https://harpers.org) -
[National Review](https://www.nationalreview.com) -
[The American Interest](https://www.the-american-interest.com) -
[The Atlantic](https://www.theatlantic.com) -
[The Christian Science Monitor](https://www.csmonitor.com) -
[The Nation](https://www.thenation.com) -
[The New Republic](https://newrepublic.com) -
[The New York Times](https://www.nytimes.com) -
[The New Yorker](https://www.newyorker.com) -
[The Washington Post](https://www.washingtonpost.com) -
[Vanity Fair](https://www.vanityfair.com) -
[World Politics Review](https://www.worldpoliticsreview.com)
##### Business
[Adweek](https://www.adweek.com) -
[American Affairs](https://americanaffairsjournal.org) -
[American Banker](https://www.americanbanker.com) -
[Barron's](https://www.barrons.com) -
[Bloomberg](https://www.bloomberg.com) -
[Business Insider](https://www.businessinsider.com) -
[Digiday](https://digiday.com) –
[Fortune](https://fortune.com) -
[Harvard Business Review](https://www.hbr.org) -
[Inc.com](https://www.inc.com) -
[MIT Sloan Management Review](https://sloanreview.mit.edu) -
[Modern Healthcare](https://www.modernhealthcare.com) -
[Quartz](https://qz.com) -
[Seeking Alpha](https://seekingalpha.com) -
[The Business Journals](https://www.bizjournals.com) -
[The Wall Street Journal](https://www.wsj.com)
##### Sports
[The Athletic](https://theathletic.com)
##### Tech/Science
[Chemical & Engineering News](https://cen.acs.org) -
[Dark Reading](https://www.darkreading.com) -
[MIT Technology Review](https://www.technologyreview.com) -
[Towards Data Science](https://www.towardsdatascience.com) -
[Wired](https://www.wired.com) -
[Scientific American](https://www.scientificamerican.com)*
#### Encyclopedia/Book library/Knowledge base
[Encyclopedia Britannica](https://www.britannica.com) -
[Glassdoor](https://www.glassdoor.com) -
[Loeb Classical Library](https://www.loebclassics.com) -
[Philosophy Now](https://philosophynow.org) -
[Quora](https://www.quora.com) -
[Scribd](http://www.scribd.com) -
[Statista](https://www.statista.com)
##### Blogs
[Medium](https://www.medium.com) (all sites) -
[SofRep](https://sofrep.com) -
[The Daily Beast](https://www.thedailybeast.com)*

##### Local US news
[Baltimore Sun](https://www.baltimoresun.com) -
[Crain's Chicago Business](https://www.chicagobusiness.com) -
[Chicago Tribune](https://www.chicagotribune.com) -
[Daily Press](https://www.dailypress.com) -
[Hartford Courant](https://www.courant.com) -
[Los Angeles Business Journal](https://labusinessjournal.com) -
[Los Angeles Times](https://www.latimes.com) -
[Miami Herald](https://www.miamiherald.com) -
[Mountain View Voice](https://www.mv-voice.com) -
[New York Magazine](https://www.nymag.com) -
[Orange County Register](https://www.ocregister.com) -
[Orlando Sentinel](https://www.orlandosentinel.com) -
[Palo Alto Online](https://www.paloaltoonline.com) -
[Pittsburgh Post Gazette](https://post-gazette.com) -
[San Diego Union Tribune](https://sandiegouniontribune.com) -
[San Francisco Chronicle](https://www.sfchronicle.com) -
[SunSentinel](https://www.sun-sentinel.com) -
[The Boston Globe](https://www.bostonglobe.com) -
[The Denver Post](https://www.denverpost.com) -
[The Mercury News](https://www.mercurynews.com) -
[The Morning Call](https://www.mcall.com) -
[The Seattle Times](https://www.seattletimes.com) -
[The News-Gazette](https://www.news-gazette.com) -
[The Philadelphia Inquirer](https://www.inquirer.com) -
[The Sacramento Bee](https://www.sacbee.com)* -
[Winston-Salem Journal](https://www.journalnow.com)

#### Australia/New Zealand
[Bendigo Advertiser](https://www.bendigoadvertiser.com.au) -
[Cairns Post](https://www.cairnspost.com.au) –
[Central Western Daily](https://www.centralwesterndaily.com.au) -
[Daily Liberal](https://www.dailyliberal.com.au) -
[Gold Coast Bulletin](https://www.goldcoastbulletin.com.au) –
[Herald Sun](https://www.heraldsun.com.au) –
[Illawarra Mercury](https://www.illawarramercury.com.au) -
[New Zealand Herald](https://www.nzherald.co.nz) -
[Newcastle Herald](https://www.newcastleherald.com.au) -
[Northern Territory News](https://www.ntnews.com.au) –
[The Advertiser/AdelaideNow](https://www.adelaidenow.com.au) –
[The Advocate](https://www.theadvocate.com.au) -
[The Age](https://www.theage.com.au) -
[The Australian](https://www.theaustralian.com.au) -
[The Border Mail](https://www.bordermail.com.au) -
[The Canberra Times](https://www.canberratimes.com.au) -
[The Courier](https://www.thecourier.com.au) -
[The Courier-Mail](https://www.couriermail.com.au) –
[The Daily Advertiser](https://www.dailyadvertiser.com.au) -
[The Daily Telegraph](https://www.dailytelegraph.com.au) –
[The Examiner](https://www.examiner.com.au) -
[The Mercury Tasmania](https://www.themercury.com.au) -
[The Northern Daily Leader](https://www.northerndailyleader.com.au) -
[The Port Macquarie News](https://www.portnews.com.au) -
[The Saturday Paper](https://www.thesaturdaypaper.com.au) -
[The Spectator Australia](https://www.spectator.com.au) -
[The Standard](https://www.standard.net.au) -
[The Sydney Morning Herald](https://www.smh.com.au) –
[The Weekly Times](https://www.weeklytimesnow.com.au) –
[Townsville Bulletin](https://www.townsvillebulletin.com.au) -
[WAtoday](https://www.watoday.com.au)

##### > Financial
[Eureka Report](https://www.eurekareport.com.au) -
[Intelligent Investor](https://www.intelligentinvestor.com.au) -
[Switzer Report](https://switzersuperreport.com.au) -
[The Australian Financial Review](https://www.afr.com)

#### Canada
[National Post](https://www.nationalpost.com) -
[Le Devoir](https://www.ledevoir.com) -
[The Toronto Star](https://www.thestar.com) -
[The Globe and Mail](https://www.theglobeandmail.com)

#### Europe
##### United Kingdom/Ireland
[Financial News](https://www.fnlondon.com) -
[Financial Times](https://www.ft.com) -
[London Review of Books](https://www.lrb.co.uk) -
[The Athletic UK](https://theathletic.com) -
[The Economist](https://www.economist.com) -
[The Irish Times](https://www.irishtimes.com)* -
[The New Statesman](https://www.newstatesman.com) -
[The Spectator](https://www.spectator.co.uk) -
[The Telegraph](https://www.telegraph.co.uk) -
[The Times](https://www.thetimes.co.uk) -
[The Times Literary Supplement](https://www.the-tls.co.uk)
##### France/Wallonia
[Challenges](https://www.challenges.fr) –
[L'Écho](https://lecho.be) -
[L'Opinion](https://www.lopinion.fr) –
[La Dépêche](https://www.ladepeche.fr) –
[Le Journal du Dimanche](https://lejdd.fr) –
[Le Parisien](https://www.leparisien.fr) -
[Les Échos](https://www.lesechos.fr)* -
[Libération](https://www.liberation.fr)* –
[Science & Vie](https://www.science-et-vie.com) -
[Valeurs Actuelles](https://www.valeursactuelles.com)
##### Germany/Austria
[Frankfurter Allgemeine Zeitung](https://www.faz.net) -
[Handelsblatt](https://www.handelsblatt.com) -
[Kleine Zeitung](https://www.kleinezeitung.at)
##### Italy
[Corriere Della Sera](https://www.corriere.it) -
[Il Messaggero](https://www.ilmessaggero.it) -
[La Repubblica](https://www.repubblica.it) -
[La Stampa](https://www.lastampa.it) -
[Le Scienze](https://www.lescienze.it)
##### Netherlands/Flanders
[Algemeen Dagblad](https://www.ad.nl) and regional ADR sites like
[BN DeStem](https://www.bndestem.nl) -
[Brabants Dagblad](https://www.bd.nl) -
[Eindhovens Dagblad](https://www.ed.nl) -
[Gelderlander](https://www.gelderlander.nl) -
[PZC](https://www.pzc.nl) -
[Stentor](https://www.destentor.nl) -
[Tubantia](https://tubantia.nl)\
[Dagblad van het Noorden](https://www.dvhn.nl) -
[De Morgen](https://www.demorgen.be) -
[De Tijd](https://www.tijd.be) -
[Groene Amsterdammer](https://www.groene.nl) -
[Het Financieel Dagblad](https://fd.nl) -
[Humo.be](https://www.humo.be) -
[Leeuwarder Courant](https://www.lc.nl) -
[NRC Handelsblad](https://www.nrc.nl) -
[Parool](https://www.parool.nl) -
[Telegraaf](https://www.telegraaf.nl) -
[Trouw](https://www.trouw.nl) -
[Volkskrant](https://www.volkskrant.nl) -
[Vrij Nederland](https://www.vn.nl)
##### Spain
[El País](https://elpais.com)
##### Sweden
[Aftonbladet](https://www.aftonbladet.se) -
[Dagens Nyheter](https://www.dn.se)
##### Switzerland
[Neue Zürcher Zeitung](https://www.nzz.ch)

#### East Asia
[Caixin Global](https://www.caixinglobal.com) -
[CommonWealth Magazine Taiwan](https://www.cw.com.tw) -
[Harvard Business Review Taiwan](https://www.hbrtaiwan.com) -
[Nikkei Asian Review](https://asia.nikkei.com) -
[Tech in Asia](https://www.techinasia.com) -
[The Diplomat](https://www.thediplomat.com) -
[The Japan Times](https://www.japantimes.co.jp)

#### India
[Bloomberg Quint](https://www.bloombergquint.com)* -
[LiveMint](https://www.livemint.com) -
[The Hindu](https://www.thehindu.com)

#### Israel
[Haaretz.co.il](https://www.haaretz.co.il) -
[Haaretz.com](https://www.haaretz.com) -
[The Marker](https://www.themarker.com)

#### Latin America
##### Argentina
[Clarín](https://www.clarin.com) -
[La Nación](https://www.lanacion.com.ar)
##### Brazil
[Exame](https://exame.abril.com.br) –
[Folha de S. Paulo](https://www.folha.uol.com.br) -
[O Estado de S. Paulo](https://estadao.com.br) –
[O Globo](https://oglobo.globo.com) –
[Valor Econômico](https://valor.globo.com)*
##### Chile
[El Mercurio](https://digital.elmercurio.com) -
[La Tercera](https://www.latercera.com)
##### Mexico
[Mexico News Daily](https://mexiconewsdaily.com)
##### Peru
[El Comercio](https://elcomercio.pe) -
[Gestión](https://gestion.pe)

_*free articles only._

### Sites with limited number of free articles
The free article limit can normally be bypassed by removing cookies for the site.*

Install the [Cookie Remover](https://addons.mozilla.org/en-US/firefox/addon/cookie-remover/) Add-on. Please rate it 5 stars if you find it useful.

When coming across a paywall click the cookie icon to remove the cookies then refresh the page.

_*May not always succeed_

### New site requests
You can submit a request for a new website [here](https://github.com/magnolia1234-new/bypass-paywalls-firefox-clean/issues/new). Please read the following instructions and share your results for a quicker process. Remember to check the [previous requests](https://github.com/magnolia1234-new/bypass-paywalls-firefox-clean/issues?q=is%3Aissue+label%3Aenhancement) before asking for a new website.
1. Visit an article on the site you want to bypass the paywall for and copy the article title.
2. Open up a new incognito window (Ctrl+Shift+N) and paste the article title into Google.
3. Click on the same article from the Google search results page. Or you can:
4. Disable javascript on the website by clicking the button right icon </> on the uBlock panel.
5. Refresh the page.

### Add custom site
Add your own custom site (also for testing).
Check 'Options'-link in popup-menu and go to custom sites.
By default sites' cookies are removed after page loads (to bypass article limit).
Also you can enable Googlebot user-agent or disable Javascript for (sub)domain(s).

### Troubleshooting
* This add-on works best alongside [uBlock Origin](https://addons.mozilla.org/en-US/firefox/addon/ublock-origin/).
* If a site doesn't work try turning off uBlock and refreshing.
* If you live in the EU, also consider installing the extension [I don't care about cookies](https://addons.mozilla.org/en-US/firefox/addon/i-dont-care-about-cookies) in order to remove cookie warnings.
* Make sure the (new) site is checked under Options.

### Changelog-releases
* Visit the [releases page](https://github.com/magnolia1234-new/bypass-paywalls-firefox-clean/releases).

### Pull Requests
* PRs are welcome.

### Show your support
* I am not asking for donations or anything like that, all I ask is that you star this repo.

### License
Bypass Paywalls Clean is [MIT-licensed](https://github.com/magnolia1234-new/bypass-paywalls-firefox-clean/blob/master/LICENSE).

==> v1.7.2.0.zip: bypass-paywalls-firefox-clean/README.md <==
# Bypass Paywalls Clean for Firefox

* [Installation](#installation)
* [List of supported websites](#list-of-supported-websites)
* [Sites with limited number of free articles](#sites-with-limited-number-of-free-articles)
* [New site requests](#new-site-requests)
* [Add custom site](#add-custom-site)
* [Troubleshooting](#troubleshooting)
* [Changelog-releases](#changelog-releases)
* [Pull Requests](#pull-requests)
* [Show your support](#show-your-support)
* [License](#license)

### Installation
[Download and install the latest version](https://bitbucket.org/magnolia1234/bypass-paywalls-firefox-clean/downloads)  
Here you can also find a limited permissions version (custom sites will not be working though).  
Install add-on by downloading xpi-file.

### List of supported websites
#### United States of America
##### World news
[First Things](https://www.firstthings.com) -
[Foreign Policy](https://www.foreignpolicy.com) -
[Harper's Magazine](https://harpers.org) -
[National Review](https://www.nationalreview.com) -
[The American Interest](https://www.the-american-interest.com) -
[The Atlantic](https://www.theatlantic.com) -
[The Christian Science Monitor](https://www.csmonitor.com) -
[The Nation](https://www.thenation.com) -
[The New Republic](https://newrepublic.com) -
[The New York Times](https://www.nytimes.com) -
[The New Yorker](https://www.newyorker.com) -
[The Washington Post](https://www.washingtonpost.com) -
[Vanity Fair](https://www.vanityfair.com) -
[World Politics Review](https://www.worldpoliticsreview.com)
##### Business
[Adweek](https://www.adweek.com) -
[American Affairs](https://americanaffairsjournal.org) -
[American Banker](https://www.americanbanker.com) -
[Barron's](https://www.barrons.com) -
[Bloomberg](https://www.bloomberg.com) -
[Business Insider](https://www.businessinsider.com) -
[Digiday](https://digiday.com) –
[Fortune](https://fortune.com) -
[Harvard Business Review](https://www.hbr.org) -
[Inc.com](https://www.inc.com) -
[MIT Sloan Management Review](https://sloanreview.mit.edu) -
[Modern Healthcare](https://www.modernhealthcare.com) -
[Quartz](https://qz.com) -
[Seeking Alpha](https://seekingalpha.com) -
[The Business Journals](https://www.bizjournals.com) -
[The Wall Street Journal](https://www.wsj.com)
##### Sports
[The Athletic](https://theathletic.com)
##### Tech/Science
[Chemical & Engineering News](https://cen.acs.org) -
[Dark Reading](https://www.darkreading.com) -
[MIT Technology Review](https://www.technologyreview.com) -
[Towards Data Science](https://www.towardsdatascience.com) -
[Wired](https://www.wired.com) -
[Scientific American](https://www.scientificamerican.com)*
#### Encyclopedia/Book library/Knowledge base
[Encyclopedia Britannica](https://www.britannica.com) -
[Glassdoor](https://www.glassdoor.com) -
[Loeb Classical Library](https://www.loebclassics.com) -
[Philosophy Now](https://philosophynow.org) -
[Quora](https://www.quora.com) -
[Scribd](http://www.scribd.com) -
[Statista](https://www.statista.com)
##### Blogs
[Medium](https://www.medium.com) (all sites) -
[SofRep](https://sofrep.com) -
[The Daily Beast](https://www.thedailybeast.com)*

##### Local US news
[Baltimore Sun](https://www.baltimoresun.com) -
[Crain's Chicago Business](https://www.chicagobusiness.com) -
[Chicago Tribune](https://www.chicagotribune.com) -
[Daily Press](https://www.dailypress.com) -
[Hartford Courant](https://www.courant.com) -
[Los Angeles Business Journal](https://labusinessjournal.com) -
[Los Angeles Times](https://www.latimes.com) -
[Miami Herald](https://www.miamiherald.com) -
[Mountain View Voice](https://www.mv-voice.com) -
[New York Magazine](https://www.nymag.com) -
[Orange County Register](https://www.ocregister.com) -
[Orlando Sentinel](https://www.orlandosentinel.com) -
[Palo Alto Online](https://www.paloaltoonline.com) -
[Pittsburgh Post Gazette](https://post-gazette.com) -
[San Diego Union Tribune](https://sandiegouniontribune.com) -
[San Francisco Chronicle](https://www.sfchronicle.com) -
[SunSentinel](https://www.sun-sentinel.com) -
[The Boston Globe](https://www.bostonglobe.com) -
[The Denver Post](https://www.denverpost.com) -
[The Mercury News](https://www.mercurynews.com) -
[The Morning Call](https://www.mcall.com) -
[The Seattle Times](https://www.seattletimes.com) -
[The News-Gazette](https://www.news-gazette.com) -
[The Philadelphia Inquirer](https://www.inquirer.com) -
[The Sacramento Bee](https://www.sacbee.com)* -
[Winston-Salem Journal](https://www.journalnow.com)

#### Australia/New Zealand
[Bendigo Advertiser](https://www.bendigoadvertiser.com.au) -
[Cairns Post](https://www.cairnspost.com.au) –
[Central Western Daily](https://www.centralwesterndaily.com.au) -
[Daily Liberal](https://www.dailyliberal.com.au) -
[Gold Coast Bulletin](https://www.goldcoastbulletin.com.au) –
[Herald Sun](https://www.heraldsun.com.au) –
[Illawarra Mercury](https://www.illawarramercury.com.au) -
[New Zealand Herald](https://www.nzherald.co.nz) -
[Newcastle Herald](https://www.newcastleherald.com.au) -
[Northern Territory News](https://www.ntnews.com.au) –
[The Advertiser/AdelaideNow](https://www.adelaidenow.com.au) –
[The Advocate](https://www.theadvocate.com.au) -
[The Age](https://www.theage.com.au) -
[The Australian](https://www.theaustralian.com.au) -
[The Border Mail](https://www.bordermail.com.au) -
[The Canberra Times](https://www.canberratimes.com.au) -
[The Courier](https://www.thecourier.com.au) -
[The Courier-Mail](https://www.couriermail.com.au) –
[The Daily Advertiser](https://www.dailyadvertiser.com.au) -
[The Daily Telegraph](https://www.dailytelegraph.com.au) –
[The Examiner](https://www.examiner.com.au) -
[The Mercury Tasmania](https://www.themercury.com.au) -
[The Northern Daily Leader](https://www.northerndailyleader.com.au) -
[The Port Macquarie News](https://www.portnews.com.au) -
[The Saturday Paper](https://www.thesaturdaypaper.com.au) -
[The Spectator Australia](https://www.spectator.com.au) -
[The Standard](https://www.standard.net.au) -
[The Sydney Morning Herald](https://www.smh.com.au) –
[The Weekly Times](https://www.weeklytimesnow.com.au) –
[Townsville Bulletin](https://www.townsvillebulletin.com.au) -
[WAtoday](https://www.watoday.com.au)

##### > Financial
[Eureka Report](https://www.eurekareport.com.au) -
[Intelligent Investor](https://www.intelligentinvestor.com.au) -
[Switzer Report](https://switzersuperreport.com.au) -
[The Australian Financial Review](https://www.afr.com)

#### Canada
[National Post](https://www.nationalpost.com) -
[Le Devoir](https://www.ledevoir.com) -
[The Toronto Star](https://www.thestar.com) -
[The Globe and Mail](https://www.theglobeandmail.com)

#### Europe
##### United Kingdom/Ireland
[Financial News](https://www.fnlondon.com) -
[Financial Times](https://www.ft.com) -
[London Review of Books](https://www.lrb.co.uk) -
[The Athletic UK](https://theathletic.com) -
[The Economist](https://www.economist.com) -
[The Irish Times](https://www.irishtimes.com)* -
[The New Statesman](https://www.newstatesman.com) -
[The Spectator](https://www.spectator.co.uk) -
[The Telegraph](https://www.telegraph.co.uk) -
[The Times](https://www.thetimes.co.uk) -
[The Times Literary Supplement](https://www.the-tls.co.uk)
##### France/Wallonia
[Challenges](https://www.challenges.fr) –
[L'Écho](https://lecho.be) -
[L'Opinion](https://www.lopinion.fr) –
[La Dépêche](https://www.ladepeche.fr) –
[Le Journal du Dimanche](https://lejdd.fr) –
[Le Journal du Net](https://www.journaldunet.com) -
[Le Parisien](https://www.leparisien.fr) -
[Les Échos](https://www.lesechos.fr) -
[Libération](https://www.liberation.fr)* –
[Science & Vie](https://www.science-et-vie.com) -
[Sciences et Avenir](https://www.sciencesetavenir.fr) -
[Valeurs Actuelles](https://www.valeursactuelles.com)
##### Germany/Austria
[Frankfurter Allgemeine Zeitung](https://www.faz.net) -
[Handelsblatt](https://www.handelsblatt.com) -
[Kleine Zeitung](https://www.kleinezeitung.at)
##### Italy
[Corriere Della Sera](https://www.corriere.it) -
[Il Messaggero](https://www.ilmessaggero.it) -
[La Repubblica](https://www.repubblica.it) -
[La Stampa](https://www.lastampa.it) -
[Le Scienze](https://www.lescienze.it)
##### Netherlands/Flanders
[Algemeen Dagblad](https://www.ad.nl) and regional ADR sites like
[BN DeStem](https://www.bndestem.nl) -
[Brabants Dagblad](https://www.bd.nl) -
[Eindhovens Dagblad](https://www.ed.nl) -
[Gelderlander](https://www.gelderlander.nl) -
[PZC](https://www.pzc.nl) -
[Stentor](https://www.destentor.nl) -
[Tubantia](https://tubantia.nl)\
[Dagblad van het Noorden](https://www.dvhn.nl) -
[De Morgen](https://www.demorgen.be) -
[De Tijd](https://www.tijd.be) -
[Groene Amsterdammer](https://www.groene.nl) -
[Het Financieel Dagblad](https://fd.nl) -
[Humo.be](https://www.humo.be) -
[Leeuwarder Courant](https://www.lc.nl) -
[NRC Handelsblad](https://www.nrc.nl) -
[Parool](https://www.parool.nl) -
[Telegraaf](https://www.telegraaf.nl) -
[Trouw](https://www.trouw.nl) -
[Volkskrant](https://www.volkskrant.nl) -
[Vrij Nederland](https://www.vn.nl)
##### Spain
[El País](https://elpais.com)
##### Sweden
[Aftonbladet](https://www.aftonbladet.se) -
[Dagens Nyheter](https://www.dn.se)
##### Switzerland
[Neue Zürcher Zeitung](https://www.nzz.ch)

#### East Asia
[Caixin Global](https://www.caixinglobal.com) -
[CommonWealth Magazine Taiwan](https://www.cw.com.tw) -
[Harvard Business Review Taiwan](https://www.hbrtaiwan.com) -
[Nikkei Asian Review](https://asia.nikkei.com) -
[Tech in Asia](https://www.techinasia.com) -
[The Diplomat](https://www.thediplomat.com) -
[The Japan Times](https://www.japantimes.co.jp)

#### India
[Bloomberg Quint](https://www.bloombergquint.com)* -
[LiveMint](https://www.livemint.com) -
[The Hindu](https://www.thehindu.com)

#### Israel
[Globes](https://www.globes.co.il) -
[Haaretz.co.il](https://www.haaretz.co.il) -
[Haaretz.com](https://www.haaretz.com) -
[The Marker](https://www.themarker.com)

#### Latin America
##### Argentina
[Clarín](https://www.clarin.com) -
[La Nación](https://www.lanacion.com.ar)
##### Brazil
[Exame](https://exame.abril.com.br) –
[Folha de S. Paulo](https://www.folha.uol.com.br) -
[O Estado de S. Paulo](https://estadao.com.br) –
[O Globo](https://oglobo.globo.com) –
[Valor Econômico](https://valor.globo.com)*
##### Chile
[El Mercurio](https://digital.elmercurio.com) -
[La Tercera](https://www.latercera.com)
##### Mexico
[Mexico News Daily](https://mexiconewsdaily.com)
##### Peru
[El Comercio](https://elcomercio.pe) -
[Gestión](https://gestion.pe)

_*free articles only._

### Sites with limited number of free articles
The free article limit can normally be bypassed by removing cookies for the site.*

Install the [Cookie Remover](https://addons.mozilla.org/en-US/firefox/addon/cookie-remover/) Add-on. Please rate it 5 stars if you find it useful.

When coming across a paywall click the cookie icon to remove the cookies then refresh the page.

_*May not always succeed_

### New site requests
You can submit a request for a new website [here](https://bitbucket.org/magnolia1234/bypass-paywalls-firefox-clean/issues?status=new&status=open).  
Please read the following instructions and share your results for a quicker process.  
Remember to check the [previous requests](https://bitbucket.org/magnolia1234/bypass-paywalls-firefox-clean/issues) before asking for a new website.  
1. Visit an article on the site you want to bypass the paywall for and copy the article title.  
2. Open up a new incognito window (Ctrl+Shift+N) and paste the article title into Google.  
3. Click on the same article from the Google search results page. Or you can:  
4. Disable javascript on the website by clicking the button right icon </> on the uBlock panel.  
5. Refresh the page.

### Add custom site
Add your own custom site (also for testing).  
Check 'Options'-link in popup-menu and go to custom sites.  
By default sites' cookies are removed after page loads (to bypass article limit).  
Also you can enable Googlebot user-agent or disable Javascript for (sub)domain(s).

### Troubleshooting
* This add-on works best alongside [uBlock Origin](https://addons.mozilla.org/en-US/firefox/addon/ublock-origin/).
* If a site doesn't work try turning off uBlock and refreshing.
* If you live in the EU, also consider installing the extension [I don't care about cookies](https://addons.mozilla.org/en-US/firefox/addon/i-dont-care-about-cookies) in order to remove cookie warnings.
* Make sure the (new) site is checked under Options.

### Changelog-releases
* Visit the [changelog page](https://bitbucket.org/magnolia1234/bypass-paywalls-firefox-clean/src/master/changelog.txt).
* Or check the [commits](https://bitbucket.org/magnolia1234/bypass-paywalls-firefox-clean/commits).
* [Download the latest version](https://bitbucket.org/magnolia1234/bypass-paywalls-firefox-clean/downloads)

### Pull Requests
* PRs are welcome.

### Show your support
* I am not asking for donations or anything like that, all I ask is that you star this repo.

### License
Bypass Paywalls Clean is [MIT-licensed](https://bitbucket.org/magnolia1234/bypass-paywalls-firefox-clean/src/master/LICENSE).
